@@ -1,8 +1,9 @@
 /* GDA library
- * Copyright (C) 1998-2002 The GNOME Foundation.
+ * Copyright (C) 1998-2005 The GNOME Foundation.
  *
  * AUTHORS:
  *	Rodrigo Moya <rodrigo@gnome-db.org>
+ *	Bas Driessen <bas.driessen@xobas.com>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -26,6 +27,7 @@
 #include <libgda/gda-command.h>
 #include <libgda/gda-connection.h>
 #include <libgda/gda-data-model.h>
+#include <libgda/gda-data-model-index.h>
 #include <libgda/gda-quark-list.h>
 #include <libgda/gda-transaction.h>
 
@@ -59,6 +61,8 @@ struct _GdaServerProviderClass {
 				      GdaQuarkList *params,
 				      const gchar *username,
 				      const gchar *password);
+	gboolean (* reset_connection) (GdaServerProvider *provider,
+				       GdaConnection *cnc);
 	gboolean (* close_connection) (GdaServerProvider *provider,
 				       GdaConnection *cnc);
 
@@ -75,11 +79,31 @@ struct _GdaServerProviderClass {
 	gboolean (* drop_database) (GdaServerProvider *provider,
 				    GdaConnection *cnc,
 				    const gchar *name);
+	gboolean (* create_table) (GdaServerProvider *provider,
+				   GdaConnection *cnc,
+				   const gchar *table_name,
+				   const GList *attributes_list,
+				   const GList *index_list);
+	gboolean (* drop_table) (GdaServerProvider *provider,
+				 GdaConnection *cnc,
+				 const gchar *table_name);
+	gboolean (* create_index) (GdaServerProvider *provider,
+				   GdaConnection *cnc,
+				   const GdaDataModelIndex *index,
+				   const gchar *table_name);
+	gboolean (* drop_index) (GdaServerProvider *provider,
+				 GdaConnection *cnc,
+				 const gchar *index_name,
+				 gboolean primary_key,
+				 const gchar *table_name);
 
 	GList * (* execute_command) (GdaServerProvider *provider,
 				     GdaConnection *cnc,
 				     GdaCommand *cmd,
 				     GdaParameterList *params);
+	char * (* get_last_insert_id) (GdaServerProvider *provider,
+				       GdaConnection *cnc,
+				       GdaDataModel *recset);
 
 	gboolean (* begin_transaction) (GdaServerProvider *provider,
 					GdaConnection *cnc,
@@ -103,6 +127,12 @@ struct _GdaServerProviderClass {
 	gboolean (* create_blob) (GdaServerProvider *provider,
 				  GdaConnection *cnc,
 				  GdaBlob *blob);
+	
+	gchar * (* value_to_sql_string) (GdaServerProvider *provider,
+				    GdaConnection *cnc,
+				    GdaValue *from);
+				  
+				  
 };
 
 GType    gda_server_provider_get_type (void);
@@ -112,6 +142,8 @@ gboolean gda_server_provider_open_connection (GdaServerProvider *provider,
 					      GdaQuarkList *params,
 					      const gchar *username,
 					      const gchar *password);
+gboolean gda_server_provider_reset_connection (GdaServerProvider *provider,
+					       GdaConnection *cnc);
 gboolean gda_server_provider_close_connection (GdaServerProvider *provider,
 					       GdaConnection *cnc);
 
@@ -128,11 +160,31 @@ gboolean gda_server_provider_create_database (GdaServerProvider *provider,
 gboolean gda_server_provider_drop_database (GdaServerProvider *provider,
 					    GdaConnection *cnc,
 					    const gchar *name);
+gboolean gda_server_provider_create_table (GdaServerProvider *provider,
+					   GdaConnection *cnc,
+					   const gchar *table_name,
+					   const GList *attributes_list,
+				   	   const GList *index_list);
+gboolean gda_server_provider_drop_table (GdaServerProvider *provider,
+					 GdaConnection *cnc,
+					 const gchar *table_name);
+gboolean gda_server_provider_create_index (GdaServerProvider *provider,
+					   GdaConnection *cnc,
+					   const GdaDataModelIndex *index,
+					   const gchar *table_name);
+gboolean gda_server_provider_drop_index (GdaServerProvider *provider,
+					 GdaConnection *cnc,
+					 const gchar *index_name,
+				 	 gboolean primary_key,
+					 const gchar *table_name);
 
 GList   *gda_server_provider_execute_command (GdaServerProvider *provider,
 					      GdaConnection *cnc,
 					      GdaCommand *cmd,
 					      GdaParameterList *params);
+gchar   *gda_server_provider_get_last_insert_id (GdaServerProvider *provider,
+						 GdaConnection *cnc,
+						 GdaDataModel *recset);
 
 gboolean gda_server_provider_begin_transaction (GdaServerProvider *provider,
 						GdaConnection *cnc,
@@ -157,6 +209,11 @@ gboolean gda_server_provider_create_blob (GdaServerProvider *provider,
 					  GdaConnection *cnc,
 					  GdaBlob *blob);
 
+gchar * gda_server_provider_value_to_sql_string (GdaServerProvider *provider,
+					    GdaConnection *cnc,
+					    GdaValue *from);
+	
+
 G_END_DECLS
 
 #endif
